<?php
/**
 * galo Theme Customizer
 *
 * @package galo
 * @since galo 1.0
 */

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function galo_customize_register( $wp_customize ) {
	$wp_customize->get_setting( 'blogname' )->transport         = 'postMessage';
	$wp_customize->get_setting( 'blogdescription' )->transport  = 'postMessage';
	$wp_customize->get_setting( 'header_textcolor' )->transport = 'postMessage';
}
add_action( 'customize_register', 'galo_customize_register' );

/**
 * Binds JS handlers to make Theme Customizer preview reload changes asynchronously.
 */
function galo_customize_preview_js() {
	wp_enqueue_script( 'galo_customizer', get_template_directory_uri() . '/js/customizer.js', array( 'customize-preview' ), '20130508', true );
}
add_action( 'customize_preview_init', 'galo_customize_preview_js' );

/**
 * Customizer CSS
 */
function galo_enqueue_customizer_controls_styles() {

  wp_register_style( 'galo-customizer-controls', get_template_directory_uri() . '/inc/customizer-controls.css', NULL, NULL, 'all' );
  wp_enqueue_style( 'galo-customizer-controls' );

  }

/**
 * Customizer Admin JS
 */
add_action( 'customize_controls_print_styles', 'galo_enqueue_customizer_controls_styles' );

function galo_enqueue_customizer_admin_scripts() {

  wp_register_script( 'customizer-admin-js', get_template_directory_uri() . '/js/customizer-admin.js', array( 'jquery' ), NULL, true );
  wp_enqueue_script( 'customizer-admin-js' );

  }

add_action( 'customize_controls_print_footer_scripts', 'galo_enqueue_customizer_admin_scripts' );

/**
 * Customizer
 *
 * @since galo 1.0
 */
function galo_theme_customizer( $wp_customize ) {
	/*--------------------------------------------------------------
		Layout
	--------------------------------------------------------------*/
	$wp_customize->add_section( 'galo_layout_section' , array(
	    'title' => __( 'Layout', 'galo' ),
	    'priority' => 20,
	    'description' => 'Layout Customization',
	) );

	$wp_customize->add_setting('galo_sidebar_position', array(
		'default' => 'right',
	));

	$wp_customize->add_control('galo_sidebar_position', array(
		'label' => __('Blog Sidebar Position', 'galo'),
		'section' => 'galo_layout_section',
		'settings' => 'galo_sidebar_position',
		'type' => 'select',
		'choices' => array(
			'right' => 'left',
			'left' => 'right'
		),
	));

	/*--------------------------------------------------------------
		Colors
	--------------------------------------------------------------*/
	/* Header Background Color */
    $wp_customize->add_setting( 'galo_header_bg_color', array(
        'default' => '#f5df92',
    ) );

	$wp_customize->add_control( new WP_Customize_Color_Control ( $wp_customize, 'galo_header_bg_color', array(
		'label' => __( 'Header Background Color', 'galo' ),
		'priority' => 1,
		'section' => 'colors',
		'settings' => 'galo_header_bg_color',
	) ) );

	/* Header Title Color */
    $wp_customize->add_setting( 'galo_header_title_color', array(
        'default' => '#ffffff',
    ) );

	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'galo_header_title_color', array(
		'label' => __( 'Header Title Color', 'galo' ),
		'priority' => 2,
		'section' => 'colors',
		'settings' => 'galo_header_title_color',
	) ) );

	/* Header Tagline Color */
    $wp_customize->add_setting( 'galo_header_tagline_color', array(
        'default' => '#ffffff',
    ) );

	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'galo_header_tagline_color', array(
		'label' => __( 'Header Tagline Color', 'galo' ),
		'priority' => 3,
		'section' => 'colors',
		'settings' => 'galo_header_tagline_color',
	) ) );

	/* Menu Link Color */
    $wp_customize->add_setting( 'galo_menu_link_color', array(
        'default' => '#cba213',
    ) );

	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'galo_menu_link_color', array(
		'label' => __( 'Menu Link Color', 'galo' ),
		'priority' => 4,
		'section' => 'colors',
		'settings' => 'galo_menu_link_color',
	) ) );

	/* Menu Link Hover Color */
    $wp_customize->add_setting( 'galo_menu_link_hover_color', array(
        'default' => '#ffffff',
    ) );

	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'galo_menu_link_hover_color', array(
		'label' => __( 'Menu Link Hover Color', 'galo' ),
		'priority' => 5,
		'section' => 'colors',
		'settings' => 'galo_menu_link_hover_color',
	) ) );

	/* Sub Menu Background Color */
    $wp_customize->add_setting( 'galo_sub_menu_bg_color', array(
        'default' => '#f5df92',
    ) );

	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'galo_sub_menu_bg_color', array(
		'label' => __( 'Sub Menu Background Color', 'galo' ),
		'priority' => 6,
		'section' => 'colors',
		'settings' => 'galo_sub_menu_bg_color',
	) ) );

	/* Body Font Color */
    $wp_customize->add_setting( 'galo_body_color', array(
        'default' => '#666666',
    ) );

	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'galo_body_color', array(
		'label' => __( 'Body Font Color', 'galo' ),
		'priority' => 7,
		'section' => 'colors',
		'settings' => 'galo_body_color',
	) ) );

	/* Link Color */
    $wp_customize->add_setting( 'galo_link_color', array(
        'default' => '#666666',
    ) );

	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'galo_link_color', array(
		'label' => __( 'Link Color', 'galo' ),
		'priority' => 8,
		'section' => 'colors',
		'settings' => 'galo_link_color',
	) ) );

	/* Link Hover Color */
    $wp_customize->add_setting( 'galo_hover_color', array(
        'default' => '#cccccc',
    ) );

	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'galo_hover_color', array(
		'label' => __( 'Link Hover Color', 'galo' ),
		'priority' => 9,
		'section' => 'colors',
		'settings' => 'galo_hover_color',
	) ) );

	/* Entry Title Link Color */
    $wp_customize->add_setting( 'galo_entry_title_color', array(
        'default' => '#666666',
    ) );

	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'galo_entry_title_color', array(
		'label' => __( 'Entry Title Color', 'galo' ),
		'priority' => 10,
		'section' => 'colors',
		'settings' => 'galo_entry_title_color',
	) ) );

	/* Icons Color */
    $wp_customize->add_setting( 'galo_icons_color', array(
        'default' => '#f5df92',
    ) );

	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'galo_icons_color', array(
		'label' => __( 'Icons Color', 'galo' ),
		'priority' => 11,
		'section' => 'colors',
		'settings' => 'galo_icons_color',
	) ) );

	class Galo_Customize_Alpha_Color_Control extends WP_Customize_Control {

	    public $type = 'alphacolor';
	    //public $palette = '#3FADD7,#555555,#666666, #F5f5f5,#333333,#404040,#2B4267';
	    public $palette = true;
	    public $default = '#f5df92';

	    protected function render() {
	        $id = 'customize-control-' . str_replace( '[', '-', str_replace( ']', '', $this->id ) );
	        $class = 'customize-control customize-control-' . $this->type; ?>
	        <li id="<?php echo esc_attr( $id ); ?>" class="<?php echo esc_attr( $class ); ?>">
	            <?php $this->render_content(); ?>
	        </li>
	    <?php }

	    public function render_content() { ?>
	        <label>
	            <span class="customize-control-title"><?php echo esc_html( $this->label ); ?></span>
	            <input type="text" data-palette="<?php echo $this->palette; ?>" data-default-color="<?php echo $this->default; ?>" value="<?php echo intval( $this->value() ); ?>" class="galo-color-control" <?php $this->link(); ?>  />
	        </label>
	    <?php }
	}

	/* Portfolio Hover Color */
    $wp_customize->add_setting( 'galo_portfolio_color', array(
        'default' => '#f5df92',
    ) );

	$wp_customize->add_control( new Galo_Customize_Alpha_Color_Control( $wp_customize, 'galo_portfolio_color', array(
		'label' => __( 'Portfolio Hover Color', 'galo' ),
		'palette' => true,
		'priority' => 12,
		'section' => 'colors',
		'settings' => 'galo_portfolio_color',
	) ) );

	/* Footer Background Color */
    $wp_customize->add_setting( 'galo_footer_bg_color', array(
        'default' => '#f2f2f2',
    ) );

	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'galo_footer_bg_color', array(
		'label' => __( 'Footer Background Color', 'galo' ),
		'priority' => 13,
		'section' => 'colors',
		'settings' => 'galo_footer_bg_color',
	) ) );

	/* Footer Text Color */
    $wp_customize->add_setting( 'galo_footer_text_color', array(
        'default' => '#666666',
    ) );

	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'galo_footer_text_color', array(
		'label' => __( 'Footer Text Color', 'galo' ),
		'priority' => 14,
		'section' => 'colors',
		'settings' => 'galo_footer_text_color',
	) ) );

	/* Footer Link Color */
    $wp_customize->add_setting( 'galo_footer_link_color', array(
        'default' => '#666666',
    ) );

	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'galo_footer_link_color', array(
		'label' => __( 'Footer Link Color', 'galo' ),
		'priority' => 15,
		'section' => 'colors',
		'settings' => 'galo_footer_link_color',
	) ) );

	/*--------------------------------------------------------------
		Footer Credits
	--------------------------------------------------------------*/
	$wp_customize->add_section( 'galo_footer_section' , array(
	    'title'       => __( 'Footer Credits', 'galo' ),
	    'priority'    => 80,
	    'description' => 'Custom Footer Credits',
	) );

	$wp_customize->add_setting('galo_footer');

	$wp_customize->add_control(
	    'galo_footer',
	    array(
	        'label' => 'Footer Credits',
	        'section' => 'galo_footer_section',
	        'type' => 'text',
	    )
	);

	/*--------------------------------------------------------------
		Custom CSS
	--------------------------------------------------------------*/
	class galo_Customize_Textarea_Control extends WP_Customize_Control {
	    public $type = 'textarea';
	 
	    public function render_content() {
	        ?>
	            <label>
	                <span class="customize-control-title"><?php echo esc_html( $this->label ); ?></span>
	                <textarea rows="5" style="width:100%;" <?php $this->link(); ?>><?php echo esc_textarea( $this->value() ); ?></textarea>
	            </label>
	        <?php
	    }
	}

	$wp_customize->add_section( 'galo_css_section' , array(
	    'title'       => __( 'Custom CSS', 'galo' ),
	    'priority'    => 90,
	    'description' => 'You can add your custom CSS',
	) );

	$wp_customize->add_setting( 'galo_css' );
	 
	$wp_customize->add_control(
	    new galo_Customize_Textarea_Control(
	        $wp_customize,
	        'galo_css',
	        array(
	            'label' => 'Custom CSS',
	            'section' => 'galo_css_section',
	            'settings' => 'galo_css'
	        )
	    )
	);

	/*--------------------------------------------------------------
		Footer Scripts
	--------------------------------------------------------------*/
	$wp_customize->add_section( 'galo_scripts_section' , array(
	    'title'       => __( 'Custom Footer Scripts', 'galo' ),
	    'priority'    => 100,
	    'description' => 'You can add your custom Scripts in the footer without the tag "script". For example: google analytics.',
	) );

	$wp_customize->add_setting( 'galo_scripts' );
	 
	$wp_customize->add_control(
	    new galo_Customize_Textarea_Control(
	        $wp_customize,
	        'galo_scripts',
	        array(
	            'label' => 'Custom Scripts',
	            'section' => 'galo_scripts_section',
	            'settings' => 'galo_scripts'
	        )
	    )
	);
}
add_action('customize_register', 'galo_theme_customizer');

/**
 * Customizer Apply Style
 *
 * @since galo 1.0
 */
if ( ! function_exists( 'galo_apply_style' ) ) :
  	
  	function galo_apply_style() {
		if ( get_theme_mod('galo_sidebar_position') || 
			 get_theme_mod('galo_header_bg_color') || 
			 get_theme_mod('galo_header_title_color') || 
			 get_theme_mod('galo_header_tagline_color') || 
			 get_theme_mod('galo_menu_link_color') || 
			 get_theme_mod('galo_menu_link_hover_color') || 
			 get_theme_mod('galo_sub_menu_bg_color') || 
			 get_theme_mod('galo_body_color') || 
			 get_theme_mod('galo_link_color') || 
			 get_theme_mod('galo_hover_color') || 
			 get_theme_mod('galo_entry_title_color') || 
			 get_theme_mod('galo_icons_color') || 
			 get_theme_mod('galo_portfolio_color') || 
			 get_theme_mod('galo_footer_bg_color') || 
			 get_theme_mod('galo_footer_text_color') || 
			 get_theme_mod('galo_footer_link_color') || 
			 get_theme_mod('galo_css')
		) { 
		?>
			<style id="galo-style-settings">
				<?php if ( get_theme_mod('galo_sidebar_position') == 'left' ) : ?>
					@media (min-width: 1024px) {
						.blog .column,
						.single .column {
							float: <?php echo get_theme_mod('galo_sidebar_position'); ?>;
						}
						
						.widget-area {
							border-left: 1px solid #f2f2f2;
							border-right: 0;
						}
					}
				<?php endif; ?>
				
				<?php if ( get_theme_mod('galo_header_bg_color') ) : ?>
					.site-header {
						background-color: <?php echo get_theme_mod('galo_header_bg_color');  ?>;
					}
				<?php endif; ?>

				<?php if ( get_theme_mod('galo_header_title_color') ) : ?>
					.site-title a {
						color: <?php echo get_theme_mod('galo_header_title_color');  ?> !important;
					}
				<?php endif; ?>

				<?php if ( get_theme_mod('galo_header_tagline_color') ) : ?>
					.site-description {
						color: <?php echo get_theme_mod('galo_header_tagline_color');  ?>;
					}
				<?php endif; ?>

				<?php if ( get_theme_mod('galo_menu_link_color') ) : ?>
					.main-navigation a,
					.main-navigation a:visited,
					button.menu-toggle {
						color: <?php echo get_theme_mod('galo_menu_link_color');  ?>;
					}
				<?php endif; ?>

				<?php if ( get_theme_mod('galo_menu_link_hover_color') ) : ?>
					.main-navigation a:hover,
					button.menu-toggle a:hover {
						color: <?php echo get_theme_mod('galo_menu_link_hover_color');  ?>;
					}
				<?php endif; ?>

				<?php if ( get_theme_mod('galo_sub_menu_bg_color') ) : ?>
					.main-navigation ul ul {
						background-color: <?php echo get_theme_mod('galo_sub_menu_bg_color');  ?>;
					}
				<?php endif; ?>

				<?php if ( get_theme_mod('galo_body_color') ) : ?>
					body,
					button,
					input,
					select,
					textarea {
						color: <?php echo get_theme_mod('galo_body_color');  ?>;
					}
				<?php endif; ?>

				<?php if ( get_theme_mod('galo_link_color') ) : ?>
					a,
					a:visited {
						color: <?php echo get_theme_mod('galo_link_color');  ?>;
					}
				<?php endif; ?>
			
				<?php if ( get_theme_mod('galo_hover_color') ) : ?>
					a:hover,
					a:focus,
					a:active {
						color: <?php echo get_theme_mod('galo_hover_color');  ?>;
					}
				<?php endif; ?>

				<?php if ( get_theme_mod('galo_entry_title_color') ) : ?>
					.entry-title,
					.entry-title a {
						color: <?php echo get_theme_mod('galo_entry_title_color');  ?>;
					}
				<?php endif; ?>

				<?php if ( get_theme_mod('galo_icons_color') ) : ?>
					.social {
						background-color: <?php echo get_theme_mod('galo_icons_color');  ?>;
					}
				<?php endif; ?>

				<?php if ( get_theme_mod('galo_portfolio_color') ) : ?>
					.masonry-wrap {
						background-color: <?php echo get_theme_mod('galo_portfolio_color');  ?>;
					}
				<?php endif; ?>

				<?php if ( get_theme_mod('galo_footer_bg_color') ) : ?>
					.site-footer {
						background-color: <?php echo get_theme_mod('galo_footer_bg_color');  ?>;
					}
				<?php endif; ?>

				<?php if ( get_theme_mod('galo_footer_text_color') ) : ?>
					.site-info {
						color: <?php echo get_theme_mod('galo_footer_text_color');  ?>;
					}
				<?php endif; ?>

				<?php if ( get_theme_mod('galo_footer_bg_color') ) : ?>
					.site-info a {
						color: <?php echo get_theme_mod('galo_footer_link_color');  ?>;
					}
				<?php endif; ?>
			</style>
			<style id="galo-custom-css">
				<?php if ( get_theme_mod('galo_css') ) : ?>
					<?php echo get_theme_mod('galo_css');  ?>;
				<?php endif; ?>
			</style>
		<?php
    }
}
endif;
add_action( 'wp_head', 'galo_apply_style' );

/**
 * Customizer Footer
 *
 * @since galo 1.0
 */
if ( ! function_exists( 'galo_apply_footer' ) ) :
  	
  	function galo_apply_footer() {	
		if ( get_theme_mod('galo_scripts') ) { 
		?>

		<script id="galo-custom-scripts">
			<?php if ( get_theme_mod('galo_scripts') ) : ?>
				<?php echo get_theme_mod('galo_scripts');  ?>;
			<?php endif; ?>
		</script>
		<?php
    }
}
endif;
add_action('wp_footer', 'galo_apply_footer');