<?php
/**
 * galo Shortcodes
 *
 * @package galo
 * @since galo 1.0
 */

/**
 * TABLE OF CONTENTS:
 ***********************
 * 1.0 - Dropcap
 * 2.0 - Columns
 * 3.0 - Buttons
 * 4.0 - Alerts
 * 5.0 - Icons
 * 6.0 - Highlights
 * 7.0 - Dividers
 * 8.0 - Archive
 * 9.0 - Portfolio Grid 2
 * 10.0 - Portfolio Grid 3
 * 11.0 - Portfolio Grid 4
 ***********************
 */

/**
 * Remove <p></p> before and after the shortcode
 *
 * @since galo 1.0
 */
function shortcode_empty_paragraph_fix($content){   
    $array = array (
        '<p>[' => '[', 
        ']</p>' => ']', 
        ']<br />' => ']'
    );

    $content = strtr($content, $array);

    return $content;
}
add_filter('the_content', 'shortcode_empty_paragraph_fix');

/**
 * 1.0 Dropcap
 *
 * @since galo 1.0
 */
function galo_dropcap_shortcode( $atts, $content = null ) {
	return '<span class="dropcap">' . $content . '</span>';
}
add_shortcode( 'dropcap', 'galo_dropcap_shortcode' );

/**
 * 2.0 Columns
 *
 * @since galo 1.0
 */
function galo_columns() {
	add_shortcode('row-start', 'galo_row_start');
	add_shortcode('row-end', 'galo_row_end');
	add_shortcode('half', 'galo_half');
	add_shortcode('one-third', 'galo_one_third');
	add_shortcode('two-thirds', 'galo_two_thirds');
	add_shortcode('one-fourth', 'galo_one_fourth');
	add_shortcode('three-fourths', 'galo_three_fourths');
	add_shortcode('one-fifth', 'galo_one_fifth');
	add_shortcode('four-fifths', 'galo_four_fifths');
	add_shortcode('one-sixth', 'galo_one_sixth');
	add_shortcode('five-sixths', 'galo_five_sixths');
}
add_action( 'wp_head', 'galo_columns' );

function galo_row_start( $atts ) {
	return '<div class="row-shortcode clear">';
}

function galo_row_end( $atts ) {
	return '</div>';
}

function galo_half( $atts, $content = null ) {
	return '<div class="column half">' . do_shortcode($content) . '</div>';
}

function galo_one_third( $atts, $content = null ) {
	return '<div class="column third">' . do_shortcode($content) . '</div>';
}

function galo_two_thirds( $atts, $content = null ) {
	return '<div class="column two-thirds">' . do_shortcode($content) . '</div>';
}

function galo_one_fourth( $atts, $content = null ) {
	return '<div class="column fourth">' . do_shortcode($content) . '</div>';
}

function galo_three_fourths( $atts, $content = null ) {
	return '<div class="column three-fourths">' . do_shortcode($content) . '</div>';
}

function galo_one_fifth( $atts, $content = null ) {
	return '<div class="column fifth">' . do_shortcode($content) . '</div>';
}

function galo_four_fifths( $atts, $content = null ) {
	return '<div class="column four-fifths">' . do_shortcode($content) . '</div>';
}

function galo_one_sixth( $atts, $content = null ) {
	return '<div class="column sixth">' . do_shortcode($content) . '</div>';
}

function galo_five_sixths( $atts, $content = null ) {
	return '<div class="column five-sixths">' . do_shortcode($content) . '</div>';
}

/**
 * 3.0 Buttons
 *
 * @since galo 1.0
 */
function galo_button( $atts, $content = null ) {
	extract(shortcode_atts(array(
		'url' => '#',
		'target' => '_self',
		'color' => 'grey',
		'size' => 'small',
		'type' => 'square',
		'display' => '',
		'title' => '',
		'class' => '',
		'rel' => ''
    ), $atts));
	
   return '<a target="'.$target.'" class="button '.$size.' '.$color.' '. $type .' '. $class .' '. $display .'" href="'.$url.'" title="' . $title . '" rel="' . $rel . '">' . do_shortcode($content) . '</a>';
}
add_shortcode('button', 'galo_button');

/**
 * 4.0 Alerts
 *
 * @since galo 1.0
 */
function galo_alert( $atts, $content = null ) {
	extract(shortcode_atts(array(
		'color' => 'grey',
		'type' => 'square',
		'text_align' => 'center',
		'width' => '100%'
    ), $atts));
	
   return '<div class="alert '.$color.' '. $type .' '. $text_align .'" style="width:'.$width.';">' . do_shortcode($content) . '</div>';
}
add_shortcode('alert', 'galo_alert');

/**
 * 5.0 Icons
 *
 * @since galo 1.0
 */
function galo_icon( $atts, $content = null ) {
	extract(shortcode_atts(array(
		'type' => '',
		'size' => '32px'
    ), $atts));
	
   return '<span class="genericon genericon-'.$type.'" style="font-size:'.$size.'; width:'.$size.'; height:'.$size.';">' . do_shortcode($content) . '</span>';
}
add_shortcode('icon', 'galo_icon');

/**
 * 6.0 Highlights
 *
 * @since galo 1.0
 */
function galo_highlight( $atts, $content = null ) {
	extract(shortcode_atts(array(
		'color'	=> 'grey',
		'class'	=> ''
	  ), $atts ));
	  return '<span class="highlight ' . $color . ' ' . $class . '">' . do_shortcode($content) . '</span>';

}
add_shortcode('highlight', 'galo_highlight');

/**
 * 7.0 Dividers
 *
 * @since galo 1.0
 */
function galo_divider( $atts, $content = null ) {
	extract(shortcode_atts(array(
		'color'	=> 'grey',
		'type'	=> 'solid',
		'width'	=> '100%',
		'class'	=> ''
	  ), $atts ));
	  return '<hr class="divider ' . $color . ' ' . $type . ' ' . $class . '" style="width:'.$width.';">' . do_shortcode($content) . '</span>';

}
add_shortcode('divider', 'galo_divider');

/**
 * 8.0 Archive
 *
 * @since galo 1.0
 */
function galo_archive_shortcode($atts, $content = null){
   	
   	extract(shortcode_atts(
   		array(
			'posts' => '',
			'cat' => '',
			'orderby' => '',
			'order' => ''
		), 
	$atts));

	$loop = new WP_Query(
		array( 
			'order' => $order, 
			'showposts' => $posts, 
			'cat' => $cat,
			'orderby' => $orderby
		)
	);

	$list = '<h3 class="shortcode-content">' . $content . '</h3><ul class="shortcode-archive">';

	if($loop->have_posts()) : while($loop->have_posts()) : $loop->the_post();

	$list .= '<li><span class="shortcode-archive-title"><a href="' . get_permalink() . '">' . get_the_title() . '</a></span><span class="shortcode-date">' . get_the_date() . '</span></li>';

	endwhile;
	
	wp_reset_query();
	
	return $list . '</ul>';

	endif;

}
add_shortcode('archive', 'galo_archive_shortcode');

/**
 * 9.0 Portfolio Grid 2
 *
 * @since galo 1.0
 */
function galo_portfolio_grid_2_shortcode($atts){
   	
   	extract(shortcode_atts(
   		array(
			'items' => '4',
			'category' => '',
		), 
	$atts));

	$loop = new WP_Query(
		array( 
			'orderby' => 'date', 
			'order' => 'DESC' ,
			'showposts' => $items , 
			'post_type' => 'portfolio',
			'portfolio_category' => $category
		)
	);

	$list = '<div id="portfolio-shortcode"><div id="masonry-loop" class="clear">';

	if($loop->have_posts()) : while($loop->have_posts()) : $loop->the_post();

	$list .= '<div class="masonry-entry column half"><a href="' . get_permalink() . '" class="entry-link"><div class="masonry-thumb">' . get_the_post_thumbnail($post_id, 'shortcodes-thumb') . '</div><div class="masonry-wrap"><div class="masonry-inner"><div class="masonry-content"><h2 class="portfolio-title">' . get_the_title() . '</h2></div></div></div></a></div>';

	endwhile;
	
	wp_reset_query();
	
	return $list . '</div></div>';

	endif;

}
add_shortcode('portfolio-grid-2', 'galo_portfolio_grid_2_shortcode');

/**
 * 10.0 Portfolio Grid 3
 *
 * @since galo 1.0
 */
function galo_portfolio_grid_3_shortcode($atts){
   	
   	extract(shortcode_atts(
   		array(
			'items' => '4',
			'category' => '',
		), 
	$atts));

	$loop = new WP_Query(
		array( 
			'orderby' => 'date', 
			'order' => 'DESC' ,
			'showposts' => $items , 
			'post_type' => 'portfolio',
			'portfolio_category' => $category
		)
	);

	$list = '<div id="portfolio-shortcode"><div id="masonry-loop" class="clear">';

	if($loop->have_posts()) : while($loop->have_posts()) : $loop->the_post();

	$list .= '<div class="masonry-entry column third"><a href="' . get_permalink() . '" class="entry-link"><div class="masonry-thumb">' . get_the_post_thumbnail($post_id, 'shortcodes-thumb') . '</div><div class="masonry-wrap"><div class="masonry-inner"><div class="masonry-content"><h2 class="portfolio-title">' . get_the_title() . '</h2></div></div></div></a></div>';

	endwhile;
	
	wp_reset_query();
	
	return $list . '</div></div>';

	endif;

}
add_shortcode('portfolio-grid-3', 'galo_portfolio_grid_3_shortcode');

/**
 * 11.0 Portfolio Grid 4
 *
 * @since galo 1.0
 */
function galo_portfolio_grid_4_shortcode($atts){
   	
   	extract(shortcode_atts(
   		array(
			'items' => '4',
			'category' => '',
		), 
	$atts));

	$loop = new WP_Query(
		array( 
			'orderby' => 'date', 
			'order' => 'DESC' ,
			'showposts' => $items , 
			'post_type' => 'portfolio',
			'portfolio_category' => $category
		)
	);

	$list = '<div id="portfolio-shortcode"><div id="masonry-loop" class="clear">';

	if($loop->have_posts()) : while($loop->have_posts()) : $loop->the_post();

	$list .= '<div class="masonry-entry column fourth"><a href="' . get_permalink() . '" class="entry-link"><div class="masonry-thumb">' . get_the_post_thumbnail($post_id, 'shortcodes-thumb') . '</div><div class="masonry-wrap"><div class="masonry-inner"><div class="masonry-content"><h2 class="portfolio-title">' . get_the_title() . '</h2></div></div></div></a></div>';

	endwhile;
	
	wp_reset_query();
	
	return $list . '</div></div>';

	endif;

}
add_shortcode('portfolio-grid-4', 'galo_portfolio_grid_4_shortcode');